Data mining / using a database
==============================

One important motivation for developing the ``cellpy`` project is to facilitate
handling many cell testing experiments within a reasonable time and with a
"tunable" degree of automation. It is therefore convenient to be able to
couple both the meta-data (look-up) to some kind of data-base, as well as
saving the extracted key parameters to either the same or another database
(where I recommend the latter). The database(s) will be a valuable asset for
further data analyses (either using statistical methods, e.g. Bayesian
modelling, or as input to machine learning algorithms, for example deep
learning using cnn).

Meta-data database
..................

TODO.

Parameters and feature extraction
.................................

TODO.

Bayesian modelling
..................

TODO.

Example: reinforcement deep learning (resnet)
.............................................

TODO.
